@@ -6,24 +6,30 @@
 
 #pragma once
 
+#include <Plasma/Applet>
 #include <QAbstractItemModel>
-
-#include "folderplugin_private_export.h"
+#include <qqmlregistration.h>
 
 class FolderModel;
 
 class QTimer;
 
-class FOLDERPLUGIN_TESTS_EXPORT Positioner : public QAbstractItemModel
+class Positioner : public QAbstractItemModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
+    Q_PROPERTY(Plasma::Applet *applet READ applet WRITE setApplet NOTIFY appletChanged)
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PROPERTY(FolderModel *folderModel READ folderModel WRITE setFolderModel NOTIFY folderModelChanged)
     Q_PROPERTY(int perStripe READ perStripe WRITE setPerStripe NOTIFY perStripeChanged)
-    Q_PROPERTY(QStringList positions READ positions WRITE setPositions NOTIFY positionsChanged)
 
 public:
+    enum LoadAndApplyFlags {
+        None,
+        SkipPerStripeUpdate
+    };
+
     explicit Positioner(QObject *parent = nullptr);
     ~Positioner() override;
 
@@ -36,8 +42,7 @@ public:
     int perStripe() const;
     void setPerStripe(int perStripe);
 
-    QStringList positions() const;
-    void setPositions(const QStringList &positions);
+    QStringList positions() const; // Used in unit tests
 
     Q_INVOKABLE int map(int row) const;
 
@@ -50,6 +55,20 @@ public:
 
     Q_INVOKABLE void reset();
 
+    /**
+     * Loads the position configuration from a config file,
+     * then calls convertFolderModelData to convert it to
+     * proxyData which can be used later by updatePositions.
+     * @param flags is used for handling if the PerStripe value is updated
+     * on load.
+     */
+    void loadAndApplyPositionsConfig(const LoadAndApplyFlags flags = LoadAndApplyFlags::None);
+
+    /**
+     * Saves the positions in m_positions to a configuration file
+     */
+    void savePositionsConfig();
+
     /**
      * Performs the move operation in the underlying model.
      *
@@ -60,7 +79,7 @@ public:
      * @return The lowest index that was moved. Used to
      *         determine the first selected item.
      */
-    Q_INVOKABLE int move(const QVariantList &moves);
+    Q_INVOKABLE int move(const QVariantList &moves, bool save = true);
 
     QHash<int, QByteArray> roleNames() const override;
 
@@ -72,6 +91,11 @@ public:
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
+    Plasma::Applet *applet() const;
+    void setApplet(Plasma::Applet *applet);
+
+    bool screenInUse() const;
+
 #ifdef BUILD_TESTING
     QHash<int, int> proxyToSourceMapping() const
     {
@@ -87,10 +111,10 @@ Q_SIGNALS:
     void enabledChanged() const;
     void folderModelChanged() const;
     void perStripeChanged() const;
-    void positionsChanged() const;
+    void appletChanged() const;
 
 private Q_SLOTS:
-    void updatePositions();
+    void updateResolution();
     void sourceStatusChanged();
     void sourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles);
     void sourceModelAboutToBeReset();
@@ -103,6 +127,8 @@ private Q_SLOTS:
     void sourceRowsMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd, const QModelIndex &destinationParent, int destinationRow);
     void sourceRowsRemoved(const QModelIndex &parent, int first, int last);
     void sourceLayoutChanged(const QList<QPersistentModelIndex> &parents, QAbstractItemModel::LayoutChangeHint hint);
+    void onItemRenamed();
+    void onListingCompleted();
 
 private:
     void initMaps(int size = -1);
@@ -110,10 +136,15 @@ private:
     int firstRow() const;
     int lastRow() const;
     int firstFreeRow() const;
-    void applyPositions();
+    // Converts data from folderModel to proxy data
+    void convertFolderModelData();
+    // Turns proxyToSource data into positions QStringList
+    void updatePositionsList();
     void flushPendingChanges();
     void connectSignals(FolderModel *model);
     void disconnectSignals(FolderModel *model);
+    bool configurationHasResolution(const QString &resolution) const;
+    QString loadConfigData() const;
 
     bool m_enabled;
     FolderModel *m_folderModel;
@@ -126,9 +157,14 @@ private:
     QStringList m_positions;
     bool m_deferApplyPositions;
     QVariantList m_deferMovePositions;
-    QTimer *const m_updatePositionsTimer;
 
     QHash<int, int> m_proxyToSource;
     QHash<int, int> m_sourceToProxy;
     bool m_beginInsertRowsCalled = false; // used to sync the amount of begin/endInsertRows calls
+
+    QString m_resolution;
+
+    Plasma::Applet *m_applet = nullptr;
+
+    friend class PositionerTest;
 };
