@@ -10,27 +10,30 @@
 
 #include <QAbstractTableModel>
 
-#include "gamepad.h"
+#include "device.h"
 
 class AxesModel : public QAbstractTableModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(Gamepad *device MEMBER m_device NOTIFY deviceChanged REQUIRED)
+    Q_PROPERTY(Device *device READ device WRITE setDevice REQUIRED)
 
 public:
     explicit AxesModel(QObject *parent = nullptr);
 
-    int rowCount(const QModelIndex &) const override;
-    int columnCount(const QModelIndex &) const override;
+    Device *device() const;
+    void setDevice(Device *device);
+
+    int rowCount(const QModelIndex &parent) const override;
+    int columnCount(const QModelIndex &parent) const override;
 
     QVariant data(const QModelIndex &index, int role) const override;
 
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
-Q_SIGNALS:
-    void deviceChanged();
+private Q_SLOTS:
+    void onAxisValueChanged(int index);
 
 private:
-    Gamepad *m_device = nullptr;
+    Device *m_device = nullptr;
 };
