@@ -10,8 +10,14 @@
 
 #include <KSharedConfig>
 
-#include "devicesmodel.h"
+extern "C" {
+#include <libwacom/libwacom.h>
+}
+
 #include "inputsequence.h"
+#include "tabletsmodel.h"
+
+Q_DECLARE_OPAQUE_POINTER(WacomDeviceDatabase *)
 
 class TabletSettings;
 class TabletData;
@@ -19,8 +25,8 @@ class TabletData;
 class Tablet : public KQuickManagedConfigModule
 {
     Q_OBJECT
-    Q_PROPERTY(DevicesModel *toolsModel READ toolsModel CONSTANT)
-    Q_PROPERTY(DevicesModel *padsModel READ padsModel CONSTANT)
+    Q_PROPERTY(TabletsModel *tabletsModel READ tabletsModel CONSTANT)
+    Q_PROPERTY(WacomDeviceDatabase *db READ db CONSTANT)
 
 public:
     explicit Tablet(QObject *parent, const KPluginMetaData &metaData);
@@ -32,21 +38,26 @@ public:
     bool isSaveNeeded() const override;
     bool isDefaults() const override;
 
-    DevicesModel *toolsModel() const;
-    DevicesModel *padsModel() const;
+    TabletsModel *tabletsModel() const;
 
     Q_SCRIPTABLE void assignPadButtonMapping(const QString &deviceName, uint button, const InputSequence &keySequence);
     Q_SCRIPTABLE void assignToolButtonMapping(const QString &deviceName, uint button, const InputSequence &keySequence);
     Q_SCRIPTABLE InputSequence padButtonMapping(const QString &deviceName, uint button) const;
     Q_SCRIPTABLE InputSequence toolButtonMapping(const QString &deviceName, uint button) const;
 
+    Q_SCRIPTABLE QString toSerializedCurve(const QPointF &controlPoint1, const QPointF &controlPoint2);
+    // QML does not support QPair, so let's use a QList as a workaround
+    Q_SCRIPTABLE QList<QPointF> fromSerializedCurve(const QString &curve);
+
+    WacomDeviceDatabase *db() const;
+
 Q_SIGNALS:
     void settingsRestored();
 
 private:
     void refreshNeedsSave();
 
-    DevicesModel *const m_toolsModel;
-    DevicesModel *const m_padsModel;
+    TabletsModel *m_tabletsModel;
     QHash<QString, QHash<QString, QHash<uint, InputSequence>>> m_unsavedMappings;
+    WacomDeviceDatabase *m_db = nullptr;
 };
