@@ -36,11 +36,6 @@ public:
         m_buttons = buttons;
     }
 
-    void zwp_tablet_pad_v2_done() override
-    {
-        m_events->padButtonsChanged(m_path, m_buttons);
-    }
-
     void zwp_tablet_pad_v2_button(uint32_t /*time*/, uint32_t button, uint32_t state) override
     {
         Q_EMIT m_events->padButtonReceived(m_path, button, state);
@@ -81,7 +76,25 @@ public:
     {
         m_tool_x = x;
         m_tool_y = y;
-        Q_EMIT m_events->toolMotion(m_hardware_serial_hi, m_hardware_serial_lo, wl_fixed_to_double(m_tool_x), wl_fixed_to_double(m_tool_y));
+        const double pressure = m_pressure / 65535.0;
+        Q_EMIT m_events->toolMotion(m_hardware_serial_hi,
+                                    m_hardware_serial_lo,
+                                    wl_fixed_to_double(m_tool_x),
+                                    wl_fixed_to_double(m_tool_y),
+                                    pressure,
+                                    wl_fixed_to_double(m_tilt_x),
+                                    wl_fixed_to_double(m_tilt_y));
+    }
+
+    void zwp_tablet_tool_v2_pressure(uint32_t pressure) override
+    {
+        m_pressure = pressure;
+    }
+
+    void zwp_tablet_tool_v2_tilt(wl_fixed_t tilt_x, wl_fixed_t tilt_y) override
+    {
+        m_tilt_x = tilt_x;
+        m_tilt_y = tilt_y;
     }
 
     void zwp_tablet_tool_v2_down(uint32_t serial) override
@@ -99,6 +112,9 @@ public:
     uint32_t m_hardware_serial_lo = 0;
     uint32_t m_tool_x = 0;
     uint32_t m_tool_y = 0;
+    uint32_t m_pressure = 0;
+    uint32_t m_tilt_x = 0;
+    uint32_t m_tilt_y = 0;
     TabletEvents *const m_events;
 };
 
@@ -163,3 +179,5 @@ TabletEvents::TabletEvents(QQuickItem *parent)
     auto _seat = tabletClient->get_tablet_seat(seat);
     new TabletSeat(this, _seat);
 }
+
+#include "moc_tabletevents.cpp"
