@@ -7,6 +7,8 @@
 
 #pragma once
 
+#include "backends/libinputcommon.h"
+
 #include <config-build-options.h>
 
 #include <QList>
@@ -29,6 +31,8 @@ class Q_DECL_EXPORT TouchpadBackend : public QObject
 {
     Q_OBJECT
 
+    Q_PROPERTY(int deviceCount READ deviceCount CONSTANT FINAL)
+
 protected:
     explicit TouchpadBackend(QObject *parent)
         : QObject(parent)
@@ -73,18 +77,18 @@ public:
 
     virtual QStringList supportedParameters() const
     {
-        return QStringList();
+        return {};
     }
     virtual QString errorString() const
     {
         return QString();
     }
 
-    virtual QList<QObject *> getDevices() const
+    virtual QList<LibinputCommon *> inputDevices() const
     {
-        return QList<QObject *>();
+        return {};
     }
-    virtual int touchpadCount() const
+    virtual int deviceCount() const
     {
         return 0;
     }
@@ -114,25 +118,19 @@ public:
     {
     }
 
-    virtual void watchForEvents(bool /*keyboard*/)
+    virtual void watchForEvents()
     {
     }
 
-    virtual QStringList listMouses(const QStringList & /*blacklist*/)
-    {
-        return QStringList();
-    }
-
 private:
     TouchpadInputBackendMode m_mode;
 
 Q_SIGNALS:
     void touchpadStateChanged();
-    void mousesChanged();
     void touchpadReset();
     void keyboardActivityStarted();
     void keyboardActivityFinished();
 
-    void touchpadAdded(bool success);
-    void touchpadRemoved(int index);
+    void deviceAdded(bool success);
+    void deviceRemoved(int index);
 };
